@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -26,20 +26,29 @@
 namespace Oxygen
 {
 
+    //________________________________________________________________________________
+    ScrollBarData::ScrollBarData( void ):
+        _target( 0L ),
+        _updatesDelayed( true ),
+        _delay( 2 ),
+        _locked( false )
+    {}
+
+    //________________________________________________________________________________
+    ScrollBarData::~ScrollBarData( void )
+    { disconnect( _target ); }
+
     //________________________________________________________________________________
     void ScrollBarData::connect( GtkWidget* widget )
     {
 
-        _updatesDelayed = true;
-        _delay = 2;
-
         _target = widget;
         _locked = false;
         _valueChangedId.connect( G_OBJECT(widget), "value-changed", G_CALLBACK( valueChanged ), this );
     }
 
     //________________________________________________________________________________
-    void ScrollBarData::disconnect( GtkWidget* widget )
+    void ScrollBarData::disconnect( GtkWidget* )
     {
         _target = 0L;
 
