@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -55,6 +55,10 @@ namespace Oxygen
     void Gtk::CSS::merge( const Gtk::CSS& other )
     {
 
+        // merge color definitions in other
+        for( CSS::ColorDefinition::Set::const_iterator iter = other._colorDefinitions.begin(); iter != other._colorDefinitions.end(); ++iter )
+        { _colorDefinitions.insert( *iter ); }
+
         // loop over sections in other
         for( Section::List::const_iterator iter = other._sections.begin(); iter != other._sections.end(); ++iter )
         {
@@ -132,6 +136,13 @@ namespace Oxygen
 
     namespace Gtk
     {
+        //_______________________________________________________________________
+        std::ostream& operator << (std::ostream& out, const CSS::ColorDefinition& colorDefinition )
+        {
+            out << "@define-color " << colorDefinition._name << " " << colorDefinition._value << ";";
+            return out;
+        }
+
         //_______________________________________________________________________
         std::ostream& operator << (std::ostream& out, const CSS::Section& section )
         {
@@ -152,6 +163,12 @@ namespace Oxygen
         std::ostream& operator << (std::ostream& out, const CSS& rc )
         {
 
+            // dump color definitions
+            for( CSS::ColorDefinition::Set::const_iterator iter = rc._colorDefinitions.begin(); iter != rc._colorDefinitions.end(); ++iter )
+            { out << *iter << std::endl; }
+
+            out << std::endl;
+
             // dump all sections
             for( CSS::Section::List::const_iterator iter = rc._sections.begin(); iter != rc._sections.end(); ++iter )
             { out << *iter << std::endl; }
